<?php

class TermType {

	var $ID;
	var $details;
	var $tax;

	function __construct($data,$taxonomy=null) {
		if (is_object($data)) {
			$this->ID = $data->term_id;
			$this->details = $data;
		} else {
			$this->ID = $data;
			$this->details = get_term($this->ID,$taxonomy);
		}
		if ($this->details) {
			$this->tax = $this->details->taxonomy;
		}
	}

	function __toString() {
		return $this->details->name;
	}

	function __get($field) {
		switch ($field) {
			default:
				if (is_object($this->details) && property_exists($this->details,$field)) {
					return $this->details->$field;
				} else {
					return $this->getField($field);
				}
		}

	}

	function getField($field,$default=NULL) {
		$value = get_field($field,$this->tax.'_'.$this->ID);
		if (empty($value)) {
			$value = $default;
		}
		return $value;

	}
	
	function json() {
		global $wpdb;
		
		// Return serialized version of this post
		$out = array();
		
		// Details
		$out['details'] = $this->details;

		// Meta
		$out['meta'] = get_term_meta($this->ID,'',true);
		foreach ($out['meta'] as $m => $val) {
			if (count($m) == 1) {
				$out['meta'][$m] = $val[0];
			}
		}
		$out['meta']['gulf_sharing_owner'] = home_url();
		
		// Fields
		$objects = get_field_objects('term_'.$this->ID);
		$fields = get_fields('term_'.$this->ID);
		$out['fields'] = $this->getFields($fields,$objects);
		
		// Children
		$out['children'] = array();
		$children = get_posts(array(
			'post_type' => 'any',
			'numberposts' => -1,
			'tax_query' => array(
				array(
					'taxonomy' => $this->tax,
					'field' => 'id',
					'terms' => $this->ID,
				)
			)
		));
		$ids = array();
		foreach ($children as $child) {
			$ids[] = $child->ID;
		}
		if (!empty($ids)) {
			$out['children'] = $wpdb->get_col('SELECT meta_value FROM wp_postmeta WHERE meta_key="uuid" AND post_id IN ('.implode(',',$ids).')');
		}

		return $out;
		
	}
	
	function getFields($fields,$objects) {
		foreach ($fields as $field => $value) {
			$object = $objects[$field];
			switch ($object['type']) {
				case 'image':
				case 'file':
					$value = (object) $value;
					$obj = new PostType($value->ID);
					$value = $obj->json();
					break;
				
				case 'gallery':
					if (is_array($value) && count($value)) {
						foreach ($value as $i => $v) {
							$v = (object) $v;
							$obj = new PostType($v->ID);
							$value[$i] = $obj->json();
						}
					}
					break;
				
				case 'post_object':
				case 'page_link':
				case 'relationship':
					if (isset($value) && !is_array($value)) {
						$value = array($value);
					}
					if (is_array($value) && count($value)) {
						foreach ($value as $i => $v) {
							if (!is_object($v)) {
								$v = str_replace(home_url(),'',$v);
								$v = get_page_by_path($v,OBJECT,PostType::allposttypes());
							}
							$obj = new PostType($v->ID);
							$value[$i] = $obj->json();
						}
					}
					break;
				
				case 'repeater':
					if (is_array($value) && count($value)) {
						$subobjects = array();
						foreach ($object['sub_fields'] as $subobject) {
							$subobjects[$subobject['name']] = $subobject;
						}
						
						foreach ($value as $i => $v) {
							$value[$i] = $this->getFields($v,$subobjects);
						}
					}
					break;
			}
		
			$fields[$field] = $value;
		

		}
		

		return $fields;
	}	
	
	

	function processFields($fields,$objects=null,$fieldprefix='') {
		global $missinguuids;
		
		if (empty($objects)) {
			$objects = get_field_objects('term_'.$this->ID);
		}
		
		foreach ($fields as $field => $value) {
			if (isset($objects[$field])) {
				$object = $objects[$field];
				switch ($object['type']) {
					case 'image':
						$file = Image::getByUUID($value->meta->uuid);
						if (empty($file)) {
							$postid = gulf_create_image_id($value->details->guid,$value->meta->uuid);
						} else {
							$postid = $file->ID;
						}
						update_term_meta($this->ID,$fieldprefix.$field,$postid);
						break;
						
					case 'file': 
						$file = Document::getByUUID($value->meta->uuid);
						if (empty($file)) {
							$postid = gulf_create_image_id($value->details->guid,$value->meta->uuid);
						} else {
							$postid = $file->ID;
						}
						update_term_meta($this->ID,$fieldprefix.$field,$postid);
						break;
						
					case 'gallery':
						if (is_array($value) && count($value)) {
							foreach ($value as $i => $v) {
//								$postid = gulf_create_image_id($v->details->guid,$value->meta->uuid,$this->ID);
//
//								$obj = new PostType($v->ID);
//								$value[$i] = $obj->json();
							}
						}						
						break;
						
					case 'post_object':
					case 'page_link':
					case 'relationship':
						if (is_array($value) && count($value)) {
							foreach ($value as $i => $v) {
								$obj = PostType::getByUUID($v->meta->uuid);
								if (empty($obj)) {
									$missinguuids[] = $v->meta->uuid;
								} else {
									update_term_meta($this->ID,$fieldprefix.$field.'_'.$i,$obj->ID);
								}
							}
						}
						break;
						
					case 'repeater':
						if (is_array($value) && count($value)) {
							$subobjects = array();
							foreach ($object['sub_fields'] as $subobject) {
								$subobjects[$subobject['name']] = $subobject;
							}
							
							foreach ($value as $i => $v) {
								$this->processFields($v,$subobjects,$field.'_'.$i.'_');
							}
							
						}						
						

						break;
				}

			}
		}

	}
	
	
}
?>
